#include <cstdio>
#include <utility>
#include <algorithm>
#include <cassert>

using namespace std;

namespace {

unsigned n;
struct Sloka {
	unsigned first;
	unsigned second;
	unsigned position;
	bool operator <(const Sloka &other) const { return first < other.first; }
};

const size_t maxcnt = 1000;
const size_t maxval = 1000000000;
struct Moznosti {
	unsigned pocet;
	Sloka sloky[maxcnt];
} moznosti[maxcnt];

struct Rym {
	unsigned value;
	unsigned position;
	unsigned source;
	Rym(unsigned value_, unsigned position_, unsigned source_) :
		value(value_),
		position(position_),
		source(source_)
	{ }
	Rym() {};
	bool operator ==(const Rym &other) const { return value == other.value; }
	bool operator <(const Rym &other) const { return value < other.value; }
};

Rym rymy[maxcnt + 1][maxcnt];
unsigned rcnt[maxcnt + 1];
unsigned lastTested = 0;

bool compute(unsigned position, FILE *out) {
	if (moznosti[0].sloky[position].first == lastTested)
		return false;

	rcnt[0] = 1;
	lastTested = rymy[0][0].value = moznosti[0].sloky[position].first;
	for (unsigned i(0); i < n; ++ i) {
		unsigned k(0);
		rcnt[i+1] = 0;
		// Get the ones we have to continue
		for (unsigned j(0); j < rcnt[i]; ++ j) {
			// Skip over all smaller than current
			while (k < moznosti[i].pocet && moznosti[i].sloky[k].first < rymy[i][j].value)
				++ k;
			// Copy the one following from here
			while (k < moznosti[i].pocet && moznosti[i].sloky[k].first == rymy[i][j].value) {
				rymy[i + 1][rcnt[i + 1] ++] = Rym(moznosti[i].sloky[k].second, moznosti[i].sloky[k].position, j);
				++ k;
			}
		}
		// Switch to the new values
		sort(rymy[i + 1], rymy[i + 1] + rcnt[i + 1]);
		// Remove dupes
		rcnt[i + 1] = unique(rymy[i + 1], rymy[i + 1] + rcnt[i + 1]) - rymy[i + 1];
	}
	for (unsigned i(0); i < rcnt[n]; ++ i) {
		if (rymy[n][i].value == lastTested) { // Good, a solution.
			unsigned output[n];
			for (unsigned j(n); j; -- j) {
				output[j - 1] = rymy[j][i].position + 1;
				i = rymy[j][i].source;
			}
			for (unsigned i(0); i < n; ++ i)
				fprintf(out, "%u\n", output[i]);
			return true;
		}
	}
	return false;
}

}

int main(int argc, char *argv[]) {
	FILE *in = fopen("basnik.in", "rt");
	fscanf(in, "%u", &n);
	assert(n <= maxcnt);
	for (unsigned i(0); i < n; ++ i) {
		fscanf(in, "%u", &moznosti[i].pocet);
		assert(moznosti[i].pocet && moznosti[i].pocet <= maxcnt);
		for (unsigned j(0); j < moznosti[i].pocet; ++ j) {
			fscanf(in, "%u %u", &moznosti[i].sloky[j].first, &moznosti[i].sloky[j].second);
			moznosti[i].sloky[j].position = j;
			assert(moznosti[i].sloky[j].first && moznosti[i].sloky[j].first <= maxval);
			assert(moznosti[i].sloky[j].second && moznosti[i].sloky[j].second <= maxval);
		}
		sort(moznosti[i].sloky, moznosti[i].sloky + moznosti[i].pocet);
	}
	fclose(in);
	bool found(false);
	FILE *out = fopen("basnik.out", "wt");
	for (unsigned i(0); !found && i < moznosti[0].pocet; ++ i) {
		found = compute(i, out);
	}
	if (!found)
		fputs("NEEXISTUJE\n", out);
	fclose(out);
	return 0;
}
